package com.ynet.life.file.parser;

import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import org.apache.poi.hssf.usermodel.HSSFRichTextString;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;

/* loaded from: com_ynet_life_file_parser.jar:com/ynet/life/file/parser/CommonXLSFileWithTotalParser.class */
public class CommonXLSFileWithTotalParser implements CommonFileParserWithTotalInterface {
    @Override // com.ynet.life.file.parser.CommonFileParserWithTotalInterface
    public void writeToFile(List titles, List recordList, List outputFields, List outputFormats, List total, String filePathName, String encoding) throws TranFailException {
        HSSFWorkbook workBook = new HSSFWorkbook();
        HSSFSheet sheet = workBook.createSheet();
        HSSFRow row = sheet.createRow(0);
        if (total != null) {
            short s = 0;
            while (true) {
                short i = s;
                if (i >= total.size()) {
                    break;
                }
                String totalItem = (String) total.get(i);
                createCell(row, i, totalItem);
                s = (short) (i + 1);
            }
        }
        HSSFRow row2 = sheet.createRow(1);
        if (titles != null) {
            short s2 = 0;
            while (true) {
                short i2 = s2;
                if (i2 >= titles.size()) {
                    break;
                }
                String titleItem = (String) titles.get(i2);
                createCell(row2, i2, titleItem);
                s2 = (short) (i2 + 1);
            }
        }
        int rowIndex = 2;
        Iterator iterator = recordList.iterator();
        while (iterator.hasNext()) {
            Map record = (Map) iterator.next();
            int i3 = rowIndex;
            rowIndex++;
            HSSFRow row3 = sheet.createRow(i3);
            short cellIndex = 0;
            for (int i4 = 0; i4 < outputFields.size(); i4++) {
                Object obj = record.get(outputFields.get(i4)) == null ? "" : record.get(outputFields.get(i4));
                String format = (String) outputFormats.get(i4);
                String fieldValue = FileParserUtil.transformFormat(obj.toString(), format);
                short s3 = cellIndex;
                cellIndex = (short) (s3 + 1);
                createCell(row3, s3, fieldValue);
            }
        }
        FileOutputStream fileOut = null;
        try {
            try {
                fileOut = new FileOutputStream(filePathName);
                workBook.write(fileOut);
                try {
                    fileOut.close();
                } catch (IOException ex) {
                    Trace.logError("LifeFile", "I/O异常", ex);
                    throw new TranFailException("EBLN0000", "I/O异常", ex);
                }
            } catch (IOException ex2) {
                Trace.logError("LifeFile", "文件写入失败", ex2);
                throw new TranFailException("EBLN0000", "文件写入失败", ex2);
            }
        } catch (Throwable th) {
            if (fileOut != null) {
                try {
                    fileOut.close();
                } catch (IOException ex3) {
                    Trace.logError("LifeFile", "I/O异常", ex3);
                    throw new TranFailException("EBLN0000", "I/O异常", ex3);
                }
            }
            throw th;
        }
    }

    private void createCell(HSSFRow row, short index, String content) {
        row.createCell(index).setCellValue(new HSSFRichTextString(content));
    }
}
